# Summary

`aiostorage` is a Python library for performing common object storage 
operations asynchronously.

It currently supports the following object storage providers:

- [Backblaze](https://www.backblaze.com/b2/cloud-storage.html)

# Installation

`aiostorage` is available on [PyPI](https://pypi.python.org/pypi/aiostorage/) and can be installed in the usual way.

# Contributing

Follow these [Python open source contribution guidelines.](https://guyrking.com/2018/03/18/open-source-python-with-github-and-conda.html)

# Documentation

- [Code](http://aiostorage.readthedocs.io/)
- [Wiki](https://family-guy.github.io/aiostorage-wiki/)
